@@ -1,5 +1,5 @@
-/* a wrapper for freopen
-   Copyright (C) 2008-2018 Free Software Foundation, Inc.
+/* Open a file, reusing a given stream, with error checking.
+   Copyright (C) 2008-2021 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 #include "error.h"
 #include "exitfail.h"
 #include "quote.h"
-#include "stdio--.h"
 
 #include "gettext.h"
 #define _(msgid) gettext (msgid)
